<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<?php if( isset($this->layout()->mainNavigation) ): ?>
  <div class="tabs packagemanager">
    <?php
      echo $this->navigation()
        ->menu()
        ->setContainer($this->layout()->mainNavigation)
        ->render();
    ?>
  </div>
<?php endif; ?>
