<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Install_Import_Ning_Cleanup extends Install_Import_Ning_Abstract
{
  protected $_priority = 10;
  
  public function run()
  {
    
  }

  protected function  _translateRow(array $data, $key = null) {
    ;
  }
}