<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<ul class="intsall_admin_step">
	<li class="active">
    <a href="<?php echo $this->url(array('action' => 'license')) ?>">
      <span class="cont_number">
        1
      </span>
    </a>
  </li>
  <li>
    <a href="<?php echo $this->url(array('action' => 'sanity')) ?>">
      <span class="cont_number">
        2
      </span>
    </a>
  </li>
  <li>
    <a href="<?php echo $this->url(array('action' => 'db-info')) ?>">
      <span class="cont_number">
        3
      </span>
    </a>
  </li>
  <li>
    <a href="<?php echo $this->url(array('action' => 'account')) ?>">
      <span class="cont_number">
        4
      </span>
    </a>
  </li>
</ul>

<?php $this->headTitle($this->translate('Step %1$s', 1))->headTitle($this->translate('License')) ?>
<div class="install_heding_description">
	<h1>
		<?php echo $this->translate('Step 1: Enter License Key') ?>
	</h1>
	<p>
	<?php echo $this->translate('Thank you for choosing SocialEngine to build your
			community! We know you\'re excited to get started, so we\'ll help you get
			through the install process as quickly as possible. Please begin by
			entering your license key below. If you don\'t remember your license key,
			you can find it in our %s.',
			$this->htmlLink('https://socialengine.com/store/clientarea.php?action=products&module=licensing', $this->translate('client area'), array('target' => '_blank'))) ?>
	</p>
	<div class="license_form">
		<?php echo $this->form->render($this) ?>
	</div>
</div>
