<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<h2>
  Conflicting Packages
</h2>

<p>

</p>

<br />


<?php if( empty($this->conflicts) ): ?>

  <div class="ok">
    There are no packages with conflicting files.
  </div>

<?php else: ?>

  <ul>
    <?php foreach( $this->conflicts as $file => $fileConflicts ): ?>
      <li>
        <h4>
          <?php echo $file ?>
        </h4>
        <ul>
          <?php foreach( $fileConflicts as $conflictPackageKey ): ?>
            <li>
              <?php echo $conflictPackageKey ?>
            </li>
          <?php endforeach; ?>
        </ul>
        <br />
      </li>
    <?php endforeach; ?>
  </ul>

<?php endif; ?>
