<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Install_Import_Version3_AlbumPhotoTags extends Install_Import_Version3_AbstractTags
{
  protected $_fromResourceType = 'media';

  protected $_toResourceType = 'album_photo';
}