<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

defined('SEIRAN_INSTALL') or die(); // Example (pw:test) test:seiran:8bd98fb521b3b05f121560c504526a3d ?>
someUser:someRealm:someMd5
