<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<h1>
  Cannot Continue...
</h1>

<p>
  It appears that SocialEngine has already been installed.
</p>

<br />

<?php if (false): // don't show'?>
    <div>
      <?php if( empty($this->identity) ): ?>
        <?php echo $this->htmlLink(array('route' => 'login'), 'Sign In') ?>
      <?php else: ?>
        <?php echo $this->htmlLink(array('route' => 'logout'), 'Sign-out') ?>
      <?php endif; ?>
    </div>

    <br />

    <?php if( !empty($this->identity) ): ?>
      <div>

        <div>
          Logged in as:
        </div>
        <div>
          <?php echo $this->identity ?>
        </div>
        <br />

      </div>
    <?php endif; ?>
<?php endif; // don't show ?>
