<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<?php if (!$this->queryError) : ?>

    <?php echo $this->form->render($this);?>

<?php else : ?>

    <ul>
        <?php foreach ($this->errors as $error) : ?>
            <li>
                <?php echo $error ?>
            </li>
        <?php endforeach; ?>
    </ul>

<?php endif; ?>
