* , div,td{
  margin:0px;
  padding:0px;
  border:none;
  font-family:Arial, Helvetica, sans-serif;
  color:#333333;
  font-style:normal;
  font-weight:400;
  line-height:1.8;
  letter-spacing:0.5px;
  font-size:14px;
}
body{
  background:#f5f5f5;
  font-size:13px;
}
ul{
  list-style-type:none;
}
input[type=text],
input[type=password],
textarea,
select{
  border:1px solid #ccc;
  padding:10px;
  width:450px;
  height:46px;
  border-radius:10px;
	box-sizing:border-box;
  font-size:14px;
  color:#333333;
}
textarea{
  height:90px;
}
button{
  border-radius:50px;
	padding:12px 24px;
	background-color:#208ED3;
	border:1px solid #208ED3;
	color:#fff;
	outline-color:transparent !important;
  font-size:15px;
  transition:0.5s;
  box-shadow:0px 5px 10px rgba(0, 0, 0, .18);
}
button:hover{
  cursor:pointer;
  opacity:0.8;
}
a{
  text-decoration:none;
}
a:link,
a:visited,
a:hover{
  color:#208ED3;
}
a:hover,
a:-webkit-any-link{
  text-decoration:none;
}
h1{
  font-size:1.5em;
  margin-bottom:.5em;
  font-weight:600;
}
h4{
  font-weight:600;
}
.topbar_wrapper{
  width:100%;
}
.topbar{
  width:950px;
  margin:20px auto 0px auto;
	overflow:hidden;
	display:flex;
	align-items:center;
	justify-content:space-between;
}
.topbar_login{
  margin-top:60px;
}
.topbar .logo{
  overflow:hidden;
  overflow:hidden;
  text-align:center;
  display:block;
  margin:auto;
}
.topbar .logo img{
  max-width:100%;
  max-height:80px;
}
div.error{
  padding:4px 8px;
  margin-bottom:4px;
  display:inline-block;
  line-height:24px;
  -moz-border-radius:7px;
  -webkit-border-radius:7px;
  color:#8a1f11;
  border-bottom:1px solid #fbc2c4;
  background-color:#fbe3e4;
}
div.warning{
  padding:4px 8px;
  margin-bottom:4px;
  display:inline-block;
  line-height:24px;
  -moz-border-radius:7px;
  -webkit-border-radius:7px;
  color:#BC7700;
  border-bottom:1px solid #fbc2c4;
  background-color:#FFEAC8;
}
div.success{
  padding:4px 8px;
  margin-bottom:4px;
  display:inline-block;
  line-height:24px;
  -moz-border-radius:7px;
  -webkit-border-radius:7px;
  color:#1f8a11;
  border-bottom:1px solid #c2fbc4;
  background-color:#F4FFE6;
}
.main_packages{
	border-radius:10px;
	background:#fff;
	margin-top:40px !important;
}
.main_packages  .tabs.packagemanager{
	margin-top:15px;
	box-sizing:border-box;
	width:95%;
}
.content{
  padding:18px;
  width:900px;
  margin:0px auto 50px auto;
  box-shadow:0 0px 7px rgba(0, 0, 0, .05);
}
.content > .content{
  width:100%;
	box-sizing:border-box;
	margin-bottom:0;
}
.global_form{
  clear:both;
}
.global_form > div > div{
  margin-top:25px;
}
.global_form > div > div .form-wrapper{
  display:flex;
  align-items:center;
  justify-content:space-between;
  margin-top:20px;
}
.global_form > div > div .form-wrapper fieldset .form-wrapper{
  margin-top:0;
  margin-bottom:20px;
}
.global_form > div > div .form-wrapper .form-element{
  flex:1;
  margin:0;
}
.global_form > div > div .form-wrapper .form-label{
  min-width:200px;
}
.global_form > div > div .form-wrapper .form-label label{
  font-size:15px;
  font-weight:600;
}
.global_form .form-wrapper label.required,
.global_form #force.form-label{
  font-weight:600;
}
.global_form .form-options-wrapper{
  margin:1.5em 0em 1.5em 0em;
}
.global_form .form-options-wrapper input[type=radio]{
  display:inline-block;
}
.global_form .form-options-wrapper label{
  display:inline-block;
  margin-left:5px;
  cursor:pointer;
  margin-top:-1px;
  font-weight:normal;
}
.global_form .form-errors{
  margin-bottom:1.5em;
}
.global_form .form-errors li + li
{
  margin-top:.5em;
}
.global_form .errors li{
  border:2px solid #fff0f0;
  background:#fff0f0;
  color:#dc3545;
  padding:.5em .8em .5em .8em;
  -moz-border-radius:5px;
  -webkit-border-radius:5px;
}
.global_form .errors li + li{
  margin-top:.5em;
}
ul.form-notices > li{
  background:#e3f2e1;
  border:2px solid #d2e5cf;
  padding:.5em .8em .5em .8em;
  -moz-border-radius:4px;
  -webkit-border-radius:4px;
  font-weight:600;
  color:#546d50;
}
.global_form .optional{
  font-weight:normal;
  margin-left:3px;
  margin-top:-1px;
}
.global_form .form-element .description{
  margin:0px 0 10px;
  font-size:13px;
  width:450px;
}
.global_form .form-element * + .description{
  margin:5px 0 0;
}
.global_form #search-element #search{
  vertical-align:middle;
  margin-top:-2px;
}
.global_form #search-element label{
  margin-left:4px;
}
.global_form #search-label,
.global_form #submit-label{
  display:none;
}
.global_form .form-description{
  margin-bottom:15px;
  padding-left:1px;
}
.global_form #buttons-wrapper{
  margin-top:1.3em;
}
.global_form #buttons-wrapper #fieldset-buttons{
  width:100%;
  display:flex;
  align-items:center;
  justify-content:space-between;
}
.global_form #buttons-wrapper #fieldset-buttons div#back-label,
.global_form #buttons-wrapper #fieldset-buttons div#submit-label{
  display:none;
}
.install_main_packages_right .global_form #buttons-wrapper #fieldset-buttons{
  justify-content:flex-start;
}
.install_main_packages_right .global_form button{
  font-size:14px;
}
.global_form > div > div .form-wrapper .install_back_btn{
  border-color:#208ED3;
  border:1px solid #208ED3;
  background-color:transparent;
  position:relative;
  padding:8px 18px;
  border-radius:50px;
  font-weight:600;
  font-size:15px;
  box-shadow:0px 5px 10px rgba(0, 0, 0, .18);
  display:inline-block;
}
.global_form > div > div .form-wrapper #submit-wrapper button{
  position:relative;
  padding:8px 18px;
}
.global_form #useSsl-wrapper .form-label{
  display:none;
}
.global_form > div > div .form-wrapper fieldset div#batchCount-wrapper{
  margin-bottom:15px;
}
.sanity_wrapper{
  clear:both;
  overflow:hidden;
}
.sanity_wrapper > div > h3{
  overflow:hidden;
  padding:0;
  font-weight:600;
  font-size:16px;
  background-color:rgba(96, 69, 226, .06);
  padding:8px 10px;
  border-radius:5px;
}
.sanity_wrapper > div > h3 + ul{
  margin-bottom:15px;
}
.sanity_wrapper > div > ul:last-child{
  margin-bottom:0px; 
}
.sanity{
  overflow:hidden;
  padding:10px 0 15px;
}
.sanity > li{
  overflow:hidden;
  display:flex;
  align-items:center;
  justify-content:space-between;
}
.sanity > li + li{
  margin-top:15px;
}
.sanity > li > div{
  float:left;
  overflow:hidden;
  min-width:260px;
  font-weight:600;
  padding:5px 20px 5px 0px;
  font-size:15px;
}
.sanity > li > div + div{
  float:none;
  overflow:hidden;
  min-width:0px;
  font-weight:400;
  padding:12px 44px 12px 12px;
  -moz-border-radius:5px;
  -webkit-border-radius:5px;
  font-size:14px;
  flex:1;
  position:relative;
}
.sanity > li > div + div::after{
  content:'';
  position:absolute;
  right:10px;
  top:8px;
  width:28px;
  height:28px;
  border-radius:50px;
  overflow:hidden;
  background-repeat:no-repeat;
  background-size:18px;
  background-position:center;
}
.sanity .sanity-ok{
  background-color:#FBFFF9;
  border:1px solid #C8E4B6;
}
.sanity > li > div + .sanity-ok::after{
  background-image:url(../images/check.png);
  background-color:#ECFBE3;
}
.sanity .sanity-notice{
  background-color:#FCFAEB;
  border:1px solid #FFB443;
}
.sanity > li > div + .sanity-notice::after{
  background-image:url(../images/warning.png);
  background-color:#FFF3E1;
}
.sanity .sanity-error{
  background-color:#FFF8F8;
  border:1px solid #D8564D;
}
.sanity > li > div + .sanity-error::after{
  background-image:url(../images/cross.png);
  background-color:#ffe7e9;
  background-size:16px;
}
#paths label{
  margin-left:5px;
}
.sucess_admin_page .love{
  font-size:15px;
}
.love span{
  display:block;
  font-style:italic;
}
.tip{
  overflow:hidden;
  clear:both;
}
.tip > span{
  -moz-border-radius:4px;
  -webkit-border-radius:4px;
  display:inline-block;
  background-repeat:no-repeat;
  background-position:5px 8px;
  padding:6px;
  padding-left:27px;
  background-color:#faf6e4;
  float:left;
  margin-bottom:15px;
  background-image:url(../../externals/images/tip.png);
}
a.buttonlink{
  background-repeat:no-repeat;
  background-position:0px 0px;
  padding-left:21px;
  display:inline-block;
}
a.buttonlink:hover{
  text-decoration:none;
}
.packages_return{
  background-image:url(../../externals/images/back.png);
}

/* FILE UPLOADER */
.uploader .swiff-uploader-box a{
  display:none !important;
}
.uploader #upload-status{
  padding:10px 15px;
  border:1px solid #eee;
}
.uploader #upload-status .progress{
  background:url(../../../externals/fancyupload/assets/progress-bar/progress.gif);
  background-repeat:no-repeat;
  background-position:+50% 0;
  margin-right:0.5em;
  vertical-align:middle;
}
.uploader #upload-status .progress-text{
  font-size:0.9em;
  font-weight:600;
}
.uploader #upload-list{
  list-style:none;
  width:450px;
  margin:0;
  border:1px solid #eee;
  border-bottom:none;
}
.uploader #upload-list li.validation-error{
  padding-left:44px;
  display:block;
  clear:left;
  line-height:40px;
  color:#8a1f11;
  cursor:pointer;
  border-bottom:1px solid #fbc2c4;
  background:#fbe3e4 url(../../../externals/fancyupload/assets/failed.png) no-repeat 4px 4px;
}
.uploader #upload-list li.file{
  border-bottom:1px solid #eee;
  background:url(../../../externals/fancyupload/assets/file.png) no-repeat 4px 4px;
  overflow:auto;
}
.uploader #upload-list li.file.file-uploading{
  background-image:url(../../../externals/fancyupload/assets/uploading.png);
  background-color:#D9DDE9;
}
.uploader #upload-list li.file.file-success{
  background-image:url(../../../externals/fancyupload/assets/success.png);
}
.uploader #upload-list li.file.file-failed{
  background-image:url(../../../externals/fancyupload/assets/failed.png);
}
.uploader #upload-list li.file .file-name{
  font-size:1.2em;
  margin-left:44px;
  display:block;
  clear:left;
  line-height:40px;
  height:40px;
  font-weight:600;
}
.uploader #upload-list li.file .file-size{
  font-size:0.9em;
  line-height:18px;
  float:right;
  margin-top:2px;
  margin-right:6px;
}
.uploader #upload-list li.file .file-info{
  display:block;
  margin-left:44px;
  font-size:0.9em;
  line-height:20px;
}
.uploader #upload-list li.file .file-remove{
  clear:right;
  float:right;
  line-height:18px;
  margin-right:6px;
}

/* PACKAGE MANAGER MENU */
.package_manager_menu > ul{
  margin-top:8px;
  float:right;
  overflow:hidden;
}
.package_manager_menu > ul > li{
  float:left;
  padding-left:20px;
}
.package_manager_menu > ul > li > a{
  padding:5px;
  font-weight:600;
}
.package_manager_menu > ul > li.active > a{
  color:#444444;
}
/*
ADMIN TABS
*/
/* PACKAGE MANAGER MAIN */

.tabs.packagemanager{
  margin-top:15px;
}
.tabs_packagemanager > h2{
  font-size:22px;
  border-bottom:1px solid #D9D9D9;
  font-weight:700;
  margin:0 -18px 15px;
  padding:0 15px 15px;
}
.packagemanager h1{
  font-weight:600;
  font-size:20px;
}
.admin_plugins_options_addpackage{
  background-image:url(../images/admin/package_add.png);
}
.admin_plugins_options_browsepackages{
  background-image:url(../images/admin/package_browse.png);
}
.admin_packages > li{
  width:100%;
  overflow:hidden;
  font-weight:600;
  padding:14px 0;
  border-bottom:1px solid #DADADA;
  display:flex;
  align-items:center;
  justify-content:flex-start;
}
.admin_packages > li:last-child{
  border:0;
}
.admin_packages .admin_packages_title{
  display:flex;
  align-items:center;
  justify-content:flex-start;
  width:66%;
  margin-right:20px;
}
.admin_packages .admin_packages_left{
  width:64px;
  height:64px;
  overflow:hidden;
  margin-right:15px;
  border-radius:50px;
  /* background-color:rgba(96, 69, 226, .05);
  border:1px solid #e1e1e1; */
}
.admin_packages .admin_packages_left img{
  width:100%;
  height:100%;
  object-fit:cover;
  object-position:center;
}
.admin_packages_right{
  flex:1;
}
.admin_packages_right h4{
  font-size:16px;
  font-weight:600;
  margin-top:5px;
}
.admin_packages h3{
  margin-right:7px;
  margin-bottom:0px;
  font-size:1.3em;
}
.admin_packages .admin_packages_version{
  width:18%;
}
.admin_packages .admin_packages_version span{
  font-size:15px;
  color:#161616;
}
.admin_packages .admin_packages_author{
  display:block;
  color:#505050;
  font-size:14px;
  margin-top:-5px;
}
.admin_packages .admin_packages_author a{
  text-decoration:none !important;
}
.admin_packages_options a{
  border:1px solid #208ED3;
  color:#208ED3;
  font-size:15px;
  border-radius:50px;
  padding:10px 4px;
  margin-left:20px;
  text-transform:capitalize;
  transition:0.5s;
  width:80px;
  display:inline-block;
  text-align:center;
}
.admin_packages_options .package_disable{
  background-color:#F5F4FD;
  border-color:#F5F4FD ;
  color:#141414;
}
.admin_packages_options .package_delete{
  border-color:#fff2f2;
  background:#fff2f2;
  color:#dd0000;
}
.admin_packages_options a:hover{
  opacity:0.8;
}
.admin_packages .admin_packages_installable .admin_packages_title{
  background-color:#d8f5c0;
}
.admin_packages .admin_packages_installable .admin_packages_options{
  background-color:#e9fadb;
}
.admin_packages .admin_packages_warning{
  display:block;
  margin-top:5px;
  color:#f45858;
  font-size:13px;
  font-style:italic;
}
.admin_packages_add{
  background-image:url(../../externals/images/package_add.png);
}
.admin_packages .admin_packages_options ul > li:last-child{
  margin-top:12px;
}
/* CHOOSE PACKAGES */
.package_uploader_main{
  margin-bottom:5px;
}
.package_uploader_choosepackages{
  position:relative;
  padding-left:45px !important;
}
.package_uploader_choosepackages::before{
  content:'';
  width:40px;
  height:40px;
  background-color:rgba(96, 69, 226, .08);
  border-radius:50px;
  position:absolute;
  left:0;
  background-image:url(../../externals/images/addpack.png);
  background-size:26px;
  background-repeat:no-repeat;
  background-position:center;
  top:-8px;
}
.package_uploader_main > div{
  display:inline-block;
}
.package_uploader_main .upload-buttons{
  float:left;
}
.package_uploader_main .upload-status-overall{
  float:left;
  margin-left:20px;
  margin-top:2px;
}
.package_uploader .swiff-uploader-box a{
  display:none !important;
}
.package_uploader #upload-status{ 
  margin-bottom:10px;
}
.package_uploader #upload-status > *{
  margin-right:5px;
}
/* .package_uploader #upload-status .progress */
.package_uploader .progress{
  background:url(../../../externals/fancyupload/assets/progress-bar/progress.gif);
  background-repeat:no-repeat;
  background-position:+50% 0;
  margin-right:0.5em;
}
.package_uploader #upload-status .progress-text{
  font-size:0.9em;
  font-weight:600;
}
.package_uploader #upload-list li.validation-error{
  padding-left:44px;
  display:block;
  clear:left;
  line-height:40px;
  color:#8a1f11;
  cursor:pointer;
  border-bottom:1px solid #fbc2c4;
  background:#fbe3e4 url(../../../externals/fancyupload/assets/failed.png) no-repeat 4px 4px;
}
.selected-packages-list{
  list-style:none;
  margin:15px 0 0;
  border:none;
}
.selected-packages-list li.file{
  -moz-border-radius:4px;
  max-width:100%;
  overflow:hidden;
  background-color:#f7f7f7;
  border:1px solid #f1f1f1;
  margin-bottom:4px;
  border-radius:10px;
}
.selected-packages-list li.file .file-select{
  display:block;
  margin-top:3px;
  padding-right:5px;
  float:left;
}
.selected-packages-list li.file .file-name{
  display:block;
  float:left;
  min-height:28px;
  width:230px;
  margin:8px;
  padding:4px 12px 0px 4px;
  border-right:1px solid #c0d4df;
}
.selected-packages-list li.file .file-name,
.selected-packages-list li.file .file-name > label{
  font-weight:600;
}
.selected-packages-list li.file .file-name > label{
  cursor:pointer;
}
.selected-packages-list li.file .file-name input[type=checkbox]{
  margin-right:4px;
  padding-top:2px;
  margin-top:4px;
}
.selected-packages-list li.file .upload-status-current{
  display:inline-block;
  float:right;
  margin-top:12px;
  margin-right:5px;
}
.selected-packages-list li.file .upload-image{
  display:inline-block;
  float:right;
  margin-top:12px;
  margin-right:5px;
}
.selected-packages-list li.file .file-size{
  margin:8px;
  padding:4px 12px 0px 4px;
  float:right;
}
.selected-packages-list li.file .file-info{
  margin:8px;
  padding:4px 12px 0px 4px;
  display:block;
  float:left;
}
.selected-packages-list li.file .file-message{
  margin-bottom:5px;
  display:block;
}
.selected-packages-list li.file .file-package-info{
  display:block;
}
.selected-packages-list li.file .file-loading{
  background-image:url(../images/loading.gif);
  background-position:0px 50%;
  background-repeat:no-repeat;
  padding-left:24px;
}
.selected-packages-list .file-package-remove{
  margin:8px;
  padding:4px 4px 0px 4px;
  display:block;
  text-align:right;
}
.package_uploader .overall-title,
.package_uploader .upload-status-current,
.package_uploader .current-text,
.package_uploader .file-remove,
.package_uploader .current-title,
.selected-packages-list .overall-title,
.selected-packages-list .upload-status-current,
.selected-packages-list .current-text,
.selected-packages-list .file-remove,
.selected-packages-list .current-title,
#upload-status .upload-image{
  display:none;
}
#package_select_continue > *{
  display:none;
}
#package_select_continue.package_select_okay > .package_select_continue_message{
  display:block;
}
#package_select_continue.package_select_error_noselection > .package_select_noselection_message,
#package_select_continue.package_select_error_uploading > .package_select_uploading_message{
  border-radius:4px;
  display:inline-block;
  padding:.5em .7em .5em .7em;
  background-color:#FAF6E4;
}
.package_select_noselection_message{
  margin-bottom:10px;
}
/* MANAGE PREPARATION */
.admin_packages_steps_wrapper{
  overflow:hidden;
}
.admin_packages_steps{
  padding:5px;
  float:left;
  overflow:hidden;
  font-size:13px;
  background-color:#f9f9f9;
  border-radius:5px;
}
.admin_packages_steps a{
  text-decoration:none;
  color:#141414;
  cursor:default;
  outline:none;
  font-size:13px;
}
.admin_packages_steps a.active{
  font-weight:600;
}
.admin_packages_actions,
.admin_packages_dependencies,
.admin_packages_requirements,
.admin_packages_diff{
  width:100%;
}
.admin_packages_actions h3.sep,
.admin_packages_diff h3.sep,
.admin_packages_requirements h3.sep,
.admin_packages_dependencies h3.sep{
  display:block;
  margin:0 0 10px;
  border:0;
  height:auto;
}
.admin_packages_actions h3.sep > span,
.admin_packages_diff h3.sep > span,
.admin_packages_requirements h3.sep > span,
.admin_packages_dependencies h3.sep > span{
  display:block;
  position:relative;
  border:0;
  background:#fdfdfd;
  padding:5px 10px;
  border-radius:5px;
  font-weight:600;
}
.admin_packages_actions li,
.admin_packages_dependencies li,
.admin_packages_requirements li{
  margin:7px 0px 0px 10px;
}
.admin_packages_dependencies li div > span,
.admin_packages_requirements li div > span{
  -moz-border-radius:4px;
  -webkit-border-radius:4px;
  display:inline-block;
  padding:.5em .7em .5em .7em;
  color:#fff;
  margin-left:10px;
  margin-top:6px;
}
.admin_packages_dependencies li .dependency-error > span,
.admin_packages_requirements li .sanity-error > span{
  background-color:#df5b5b;
}
.admin_packages_dependencies li .dependency-notice > span,
.admin_packages_requirements li .sanity-notice > span{
  color:#555;
  background-color:#fcf5de;
  border:1px solid #e4dab6;
}
.admin_packages_dependencies li .dependency-ok > span,
.admin_packages_requirements li .sanity-ok > span{
  color:#555;
  background-color:#ddf1cf;
  border:1px solid #c8e4b6;
}

.admin_packages_diff_container{
  border:1px solid #ccc;
  width:700px;
  margin-top:10px;
  max-height:400px;
  overflow-y:auto;
}
.admin_packages_diff_package{
  margin-top:5px;
}
.admin_packages_diff_package > div{
  padding:5px 7px 5px 7px;
}
.admin_packages_diff li{
  padding:5px 7px 5px 7px;
  font-size:.8em;
  overflow:hidden;
}
.admin_packages_diff li + li{
  border-top:1px solid #eee;
}
.admin_packages_diff_filename{
  display:block;
  overflow:hidden;
  word-wrap:break-word;
}
.admin_packages_diff_fileresult{
  display:block;
  float:right;
  overflow:hidden;
  margin-left:10px;
  /* width:100px; */
  text-align:right;
}
.admin_packages_install_submit{
  margin-top:10px;
}
.admin_packages_install_submit p{
  margin-bottom:10px;
}
.admin_packages_install_submit button{
  margin-right:5px;
  font-size:14px;
  padding:10px 18px;
}
/*
PERMISSIONS CHECK AND FILE COPY
*/
.packages_perm_errors,
.packages_upload_errors{
  overflow:hidden;
  border:1px solid #ccc;
  width:600px;
  margin-top:5px;
  max-height:400px;
  overflow-y:auto;
}
.packages_perm_errors > li,
.packages_upload_errors > li{
  padding:10px;
  font-size:.8em;
  padding-left:27px;
  background-image:url(../../externals/images/error.png);
  background-repeat:no-repeat;
  background-position:5px center;
}
.packages_perm_errors > li.writeable,
.packages_upload_errors > li.success{
  background-image:url(../../externals/images/notice.png);
}
.packages_perm_errors > li + li,
.packages_upload_errors > li + li{
  border-top:1px solid #eee;
}

/*
DATABASE QUERY
*/
.package_query_results{
  padding:2px;
}
.package_query_results ul{
  border:1px solid #ccc;
  width:700px;
  margin-top:10px;
  max-height:400px;
  overflow-y:auto;
}
.package_query_results li{
  padding:10px;
  font-size:.8em;
  padding-left:27px;
}
.package_query_results li.error{
  background-image:url(../../externals/images/error.png);
  background-repeat:no-repeat;
  background-position:5px center;
}
.package_query_results li + li{
  border-top:1px solid #eee;
}

/*
PACKGE USERS LIST
*/
.package_users_list{
  width:600px;
}
.package_users_list li{
  padding:5px 15px 5px 15px;
}
.package_users_list li + li{
  border-top:1px solid #eee;
}
.package_users_list li.header{
  background-color:#E9F4FA;
  border-bottom:1px solid #AAAAAA;
  padding:7px 10px;
}
.package_users_list li.header *{
  color:#141414;
  font-size:10pt;
  font-weight:600;
}
.package_users_list .package_users_list_type{
  display:inline-block;
  width:90px;
}
.package_users_list .package_users_list_options{
  display:inline-block;
  float:right;
}

/* PACKAGE COMPARE */
._btn_mdifyed_files{
  margin:15px 0 20px;
}
._btn_mdifyed_files .buttonlink{
  padding:12px 20px;
  font-size:13px;
  font-weight:600;
  background:#208ED3;
  border-radius:50px;
  margin-right:5px;
  color:#fff;
}
.package_compare_list > li{
  padding-bottom:10px;
}
.package_compare_listitem.package_compare_listitem_hascompare .package_compare_container{
  background-color:#D8F5C0;
  border:1px solid #AFD5A5;
}
.package_compare_container{
  background-color:#fdfdfd;
  border:1px solid #f5f5f5;
  font-weight:600;
  overflow:hidden;
  padding:10px 15px;
  border-radius:10px;
}
.package_compare_list .package_compare_title{
  margin:0;
  font-size:16px;
  font-weight:500;
}
.package_compare_count{
  color:#6a6a6a;
  font-weight:600;
  margin-left:6px;
}
.package_compare_hascompare{
  color:#AAAAAA;
  font-weight:600;
  margin-left:6px;
}
.package_compare_listitem_nodifferences .package_compare_container{
  background-color:#fbfbfb;
  border:1px solid #f1f1f1;
}

.package_compare_summary > ul > li{
  float:left;
  margin-top:5px;
  padding-right:9px;
}
.package_compare_diffs{
  -moz-border-radius:4px 4px 4px 4px;
  border:1px solid #C0D4DF;
  font-weight:600;
  overflow:hidden;
  padding:8px 10px;
  width:520px;
  margin-left:30px;
  margin-top:10px;
}
.package_text_diff{
  background-color:#FAFAFA;
  border:1px solid #CCCCCC;
  border-collapse:collapse;
  width:98%;
}
.package_text_diff_title{
  background-color:#E4E4D4;
  padding:0.2em;
  text-align:left;
  background-color:#EEEEEE;
  border:1px solid #CCCCCC;
  color:#484848;
  font-size:12px;
}
.package_text_diff pre{
  white-space:pre-wrap;
}
.package_text_diff td{
  padding:2px;
  border-collapse:collapse;
  color:#484848;
  font-size:12px;
}
.package_text_diff .package_text_diff_line{
  border:1px solid #D7D7D7;
  color:#999999;
  font-size:0.8em;
  padding-right:3px;
  text-align:right;
  width:2%;
  background-color:#EEEEEE;
}
.text_diff_op_line.text_diff_op_add .package_text_diff_right,
.text_diff_op_line.text_diff_op_change .package_text_diff_right{
  background:none repeat scroll 0 0 #CCFFCC;
}
.text_diff_op_line.text_diff_op_change .package_text_diff_left,
.text_diff_op_line.text_diff_op_delete .package_text_diff_left{
  background:none repeat scroll 0 0 #FFCCCC;
}
.text_diff_op_line.text_diff_irrelevant{
  background-color:#EAF2F5;
}
/* Import styles */
.import_tools_list > li:nth-child(3n+1) .buttonlink::before{
  background-image:url(../../externals/images/ning.png);
}
.import_tools_list > li:nth-child(3n+2) .buttonlink:before{
  background-image:url(../../externals/images/phpfox.png);
}
.import_tools_list > li:nth-child(3n+3) .buttonlink:before{
  background-image:url(../../externals/images/se.png);
}
.buttonlink.import_ning{
  background-image:url(../../externals/images/package_go.png);
}
.buttonlink.import_version3{
  background-image:url(../../externals/images/package_go.png);
}
.global_form label[for=passwordRegeneration-none]
{
  display:inline;
  position:relative;
  top:-5px;
}
.global_form input#passwordRegeneration-none
{
  float:left;
}
.global_form input#mailFromAddress,
.global_form input#mailSubject,
.global_form textarea#mailTemplate
{
  width:400px;
}
.global_form textarea#mailTemplate
{
  height:250px;
}

ul.import_log_section
{
  margin-bottom:10px;
}
ul.import_log_section > li
{
  padding-bottom:15px;
}
ul.import_log_section > li > h3
{
  padding-bottom:5px;
}
ul.import_log_section > li > ul{
  padding-left:10px;
}
.import_log li{
  padding:2px 8px;
  line-height:24px;
  border:none;
}
.import_log li:first-child{
  border-top-left-radius:7px;
  border-top-right-radius:7px;
  -moz-border-radius-topleft:7px;
  -moz-border-radius-topright:7px;
  -webkit-border-top-left-radius:7px;
  -webkit-border-top-right-radius:7px;
}
.import_log li:last-child
{
  border-bottom-left-radius:7px;
  border-bottom-right-radius:7px;
  -moz-border-radius-bottomleft:7px;
  -moz-border-radius-bottomright:7px;
  -webkit-border-bottom-left-radius:7px;
  -webkit-border-bottom-right-radius:7px;
}
.import_log li,
.import_log li.notice
{
  background-color:#ddf1cf;
  border:1px solid #c8e4b6;
}
.import_log li.error
{
  background-color:#f6c4c4;
  border:1px solid #de7070;
}
.import_log li.warning
{
  background-color:#fcf5de;
  border:1px solid #e4dab6;
}
/* OTHER TOOLS */

/*
LOG BROWSER
*/
.admin_logs_container{
  width:100%;
}
.admin_logs{
  border:2px solid #ccc;
  height:370px;
  overflow-y:scroll;
  padding:8px;
  border-radius:3px;
}
.admin_logs_nav{
  margin-bottom:5px;
  display:block;
  overflow:hidden;
}
.admin_logs_nav_next{
  float:right;
  display:block;
}
.admin_logs_nav_previous{
  float:left;
  display:block;
}
.admin_logs_nav_next a,
.admin_logs_nav_previous a{
  padding:6px 12px;
  background:#208ED3;
  display:inline-block;
  border-radius:50px;
  color:#fff;
  margin-bottom:8px;
  font-size:14px;
  font-weight:500;
}
.admin_logs_nav_next a:hover,
.admin_logs_nav_previous a:hover{
  opacity:0.8;
}



/* SEARCH BOX */
.admin_search{
  max-width:100%;
  clear:both;
  overflow:hidden;
}
.search{
  +rounded(5px);
  +foreground;
  padding:0;
  float:left;
}
.admin_search button{
  font-size:14px;
  padding:12px 16px;
}
html[dir="rtl"] .search
{
  float:right;
}
.search > form{
  overflow:hidden;
  border:1px solid #ccc;
  background:#fff;
  padding:12px;
  border-radius:5px;
}
.search form > div{
  float:left;
  margin-left:10px;
}
html[dir="rtl"] .search form > div{
  float:right;
  margin-left:0px;
  margin-right:10px;
}
.search form > div:first-child{
  margin-left:0px;
}
html[dir="rtl"] .search form > div:first-child{
  margin-right:0px;
}
.search div label{
  font-size:8pt;
  font-weight:600;
  display:block;
}
.search div input, div.search div select{
  width:auto;
  margin-top:3px;
}
.search div select option{
  padding-left:3px;
}
html[dir="rtl"] .search div select option{
  padding-left:0px;
  padding-right:3px;
}
.search .buttons{
  margin-top:1em;
}

#TB_window a:link{color:#141414;}
#TB_window a:visited{color:#141414;}
#TB_window a:hover{color:#000;}
#TB_window a:active{color:#141414;}
#TB_window a:focus{color:#141414;}

#TB_overlay{
	position:absolute;
	z-index:100;
	top:0px;
	left:0px;
	background-color:#000;
}

#TB_window{
  +rounded(8px);
	position:absolute;
	z-index:102;
	text-align:left;
	background:#eee;
	color:#000;
	border:8px solid #444;
}

#TB_caption{
	height:25px;
	padding:7px 30px 10px 25px;
	float:left;
}

#TB_closeWindow{
	height:25px;
	padding:11px 25px 10px 0;
	float:right;
}

#TB_closeAjaxWindow{
	padding:5px 10px 7px 0;
	margin-bottom:1px;
	text-align:right;
	float:right;
}

#TB_ajaxWindowTitle{
	float:left;
	padding:7px 0 5px 10px;
	margin-bottom:1px;
}

#TB_title{
	background-color:#e9f4fa;
	height:33px;
	border-bottom:1px solid #d7e8f1;
}

/* hide the title bar by default */
#TB_title{
  display:none;
}
#TB_title *{
  font-weight:600;
	font-size:13pt;
}
#TB_ajaxContent{
	clear:both;
	padding:12px 15px 38px 10px;
	overflow:auto;
	text-align:left;
	line-height:1.4em;
}
#TB_ajaxContent p{
	padding:5px 0px 5px 0px;
}
#TB_load{
	position:absolute;
	display:none;
	height:100px;
	width:100px;
	z-index:101;
}
#TB_HideSelect{
	z-index:99;
	position:absolute;
	top:0;
	left:0;
	background-color:#fff;
	border:none;
}
#TB_iframeContent{
	clear:both;
	border:none;
	margin-bottom:-1px;
	margin-top:1px;
}
/* IE6 */
* html #TB_iframeContent{
	margin-bottom:1px;
}
.ning_import ul.import_log_section .status{
 width:16px;
 height:16px;
 display:inline-block;
}
.ning_import ul.import_log_section span.completed{
  background-image:url(../../externals/images/notice.png);
}
.ning_import ul.import_log_section span.in_process{
  background-image:url(../../externals/images/loading.gif);
}
.ning_import ul.import_log_section span.error{
  background-image:url(../../externals/images/error.png);
}
.ning_import ul.import_log_section .toggle_link{
  float:right;
}
.ning_import  ul.import_log_section > li{
  padding:4px;
  border-bottom:1px solid #ccc;
}
.ning_import  ul.import_log_section > li > ul{
  padding:0;
  overflow-y:auto;
  overflow-x:hidden;
  max-height:300px;
  margin:15px 25px;
  border:1px solid #ccc;
}
.ning_import  .import_log li, .import_log > li{
    border:1px solid #fff;
}
.ning_import .import_log li:first-child, 
.ning_import .import_log li:last-child{
  border-radius:0px;
  -moz-border-radius:0px;
  -webkit-border-radius:0px;
}
/* SHOW HIDE PASSWORD */
/* FOR MS EDGE */
input::-ms-reveal,
input::-ms-clear{
  display:none;
}
input[type=password]{
  padding-right:30px;	
}
#password_settings_group-wrapper,
.user_showhidepassword > i{
  position:relative;
}
#password-wrapper label{
  font-weight:600;
}
#showhidepassword-wrapper,
#showhideconfirmpassword-wrapper{
  margin-top:0;
  margin-bottom:0;
}
#showhidepassword-wrapper #showhidepassword-label,
#showhideconfirmpassword-wrapper #showhideconfirmpassword-label{
  display:none;
}
.user_showhidepassword{
	margin-top:-50px;
	float:right;
	margin-right:10px;
	cursor:pointer;
}
.admin_install_login_form .user_showhidepassword{
  margin-top:-30px;
}
.user_showhidepassword > i:before{
  content:"";
	background-size:16px;
	background-repeat:no-repeat;
	width:16px;
	height:16px;
	display:block;
}
.user_showhidepassword > .fa-eye:before{
  background-image:url(../../externals/images/hidden.png);
}
.user_showhidepassword > .fa-eye-slash:before{
  background-image:url(../../externals/images/eye.png);
}
.create-admin-form .global_form > div > div .form-wrapper{
  align-items:flex-start;
}
.create-admin-form .user_showhidepassword{
  margin-top:-78px;
}
.sdk .global_form > div > div .form-wrapper{
  align-items:flex-start;
}
.install_main_packages_right .global_form > div > div .form-wrapper{
  align-items:flex-start;
}
/*PhpFox Issue*/
div#phpfox_version-wrapper ul.form-options-wrapper{
  margin-top:0 !important;
}

/*common btn Code*/
.admin_install_btn{
  display:block;
  margin-left:auto;
  width:100%;
  text-align:right;
}
.admin_install_btn button{
  padding:8px 18px;
  position:relative;
}
/* .admin_install_btn button:before{
  content:'';
  background-image:url(../images/right_back.png);
  width:18px;
  height:18px;
  background-position:center;
  background-size:18px;
  background-repeat:no-repeat;
  position:absolute;
  right:14px;
  top:12px;
} */
.admin_install_btn .back_btn{
  background-color:#fff;
  color:#208ED3;
  float:left;
  outline:0;
  padding:8px 18px;
}
/* .admin_install_btn .back_btn:before{
  left:14px;
  right:auto;
  background-image:url(../images/back_button.png);
} */

.admin_install_btn .back_btn:hover{
  opacity:0.8;
}
._db_info_back{
  position:relative;
  top:-45px;
}
/*Step Button*/
.intsall_admin_step{
  display:flex;
  align-items:center;
  justify-content:center;
  margin:20px 0 30px;
}
.intsall_admin_step li{
  position:relative;
}
.intsall_admin_step li::after{
  content:'';
  position:absolute;
  left:0px;
  width:100px;
  height:2px;
  background-color:#FAFAFA;
  top:28px;
}
.intsall_admin_step li.active::after{
  background-color:#208ED3;
}
.intsall_admin_step li:first-child:after{
  display:none;
}
.intsall_admin_step li + li{
  padding-left:100px;
}
.intsall_admin_step li .cont_number{
  width:54px;
  height:54px;
  display:flex;
  align-items:center;
  justify-content:center;
  background-color:#FAFAFA;
  border-radius:50px;
  font-size:22px;
  font-weight:600;
  color:#141414;
}
.intsall_admin_step li a{
  text-decoration:none;
}
.intsall_admin_step .active .cont_number{
  background-color:#208ED3;
  color:#fff;
}
.install_heding_description{
  margin-bottom:15px;
}
.install_heding_description .error_desc{
  margin-bottom:15px;
}
.sanity_wrapper{
  margin-bottom:15px;
}
.warning_ads{
  background:#fff0f0;
  padding:12px 10px;
  border-radius:5px;
  color:#dc3545;
  margin-bottom:10px;
}
.warning_ads svg{
  fill:#dc3545;
  vertical-align:text-bottom;
  width:18px;
  height:18px;
  margin-right:4px;
}
/*Success Page*/
.sucess_admin_page p{
  font-weight:500;
  margin-bottom:6px;
}
.succes_btn_group{
  display:flex;
  align-items:center;
  margin-top:16px;
  justify-content:flex-end;
}
.succes_btn_group .btn{
  border-radius:50px;
  padding:10px 24px;
  font-weight:500;
  background-color:#208ED3;
  border:1px solid #208ED3;
  color:#fff;
  outline-color:transparent !important;
  font-size:15px;
  transition:0.5s;
  text-decoration:none;
  box-shadow:0px 5px 10px rgba(0, 0, 0, .18);
}
.succes_btn_group .btn-primary{
  margin-right:10px;
  background-color:#fff;
  color:#208ED3;
}
.succes_btn_group .btn:hover{
  opacity:0.8;
}
/*Login Form*/
.admin_install_login_form{
  background:#fff;
  width:400px;
  margin:30px auto 0;
  padding:20px;
  border-radius:10px;
}
.admin_install_login_form h1{
  text-align:center;
  font-size:24px;
}
.admin_install_login_form .global_form .global_form > div > div{
  margin-top:10px;
}
.admin_install_login_form .global_form > div > div .form-wrapper .form-element{
  flex:inherit;
  margin:0;
  width:100%;
}
.admin_install_login_form .global_form > div > div .form-wrapper .form-label{
  min-width:100%;
}
.admin_install_login_form .global_form > div > div .form-wrapper{
  flex-direction:column;
  align-items:flex-start;
  margin-top:15px;
}
.admin_install_login_form .global_form > div > div .form-wrapper .form-label label{
  display:block;
  margin-bottom:8px;
  text-align:left;
  font-weight:400 !important;
}
.admin_install_login_form input[type=text],
.admin_install_login_form input[type=password],
.admin_install_login_form textarea,
.admin_install_login_form select{
  width:100%;
}
.admin_install_login_form .global_form > div > div .form-wrapper button{
  width:100%;
  margin-top:0;
  float:none;
  font-weight:400;
}
.admin_install_login_back a{
  margin-top:15px;
  display:flex;
  align-items:center;
  justify-content:center;
  color:#161616;
  font-size:15px;
  border:1px solid #208ED3;
  border-radius:50px;
  padding:10px 5px;
}
.admin_install_login_back svg{
  margin-right:5px;
  fill:#161616;
}

/*Top Bar Mnanage Header*/
.topbar_manage_page{
  display:flex;
  align-items:center;
  justify-content:space-between;
  padding:15px 0;
  width:1200px;
  box-shadow:0 0px 7px rgba(0, 0, 0, .05);
  border-radius:10px;
  background:#fff;
  margin:30px auto 30px;
}
.topbar_manage_page .logo{
  padding-left:15px;
}
.topbar_manage_page .logo img{
  width:100%;
  max-height:60px;
}
.topmenu_manage_page{
  flex:1;
  margin-left:40px;
  padding-right:15px;
}
.topmenu_manage_page{
  flex:1;
  margin-left:40px;
  display:flex;
  align-items:center;
  justify-content:flex-end;
}
.topmenu_manage_page p{
  margin-right:20px;
  line-height:1.5;
}
.topmenu_manage_page .package_return_btn{
  background:#208ED3;
  padding:13px 20px;
  border-radius:50px;
  display:flex;
  align-items:center;
  justify-content:center;
  color:#fff;
  font-size:14px;
  transition:0.5s;
  box-shadow:0px 5px 10px rgba(0, 0, 0, .18);
}
.topmenu_manage_page .package_return_btn:hover{
  opacity:0.8;
}
.topmenu_manage_page .package_return_btn img{
  margin-right:6px;
  width:16px;
}
.install_main_packages{
  display:flex;
  align-items:flex-start;
  justify-content:center;
  width:1200px;
  margin:0 auto 30px;
}
.install_main_packages_left{
  width:250px;
  margin-right:30px;
  padding:15px 10px;
  box-shadow:0 0px 7px rgba(0, 0, 0, .05);
  border-radius:10px;
  background:#fff;
  position:sticky;
  top:10px;
}
.install_main_packages_left .tabs{
  margin:0;
}
.install_main_packages_right{
  flex:1;
  padding:15px;
  box-shadow:0 0px 7px rgba(0, 0, 0, .05);
  border-radius:10px;
  background:#fff;
  overflow:hidden;
}
.install_main_packages_right .global_form > div > div{
  margin-top:0;
}
.install_main_packages_right .global_form fieldset{
  font-size:16px;
}
.install_main_packages_right .global_form fieldset > *{
  margin:0px 10px;
}
.tabs .navigation li a{
  padding:12px 18px;
  display:block;
  margin-bottom:10px;
  background:transparent;
  border-radius:5px;
  font-size:16px;
  color:#161616;
  transition:0.5s;
  position:relative;
}
.tabs .navigation li:last-child a{
  margin-bottom:0;
}
.tabs .navigation li.active a,
.tabs .navigation li a:hover{
  background-color:rgba(96, 69, 226, .05);
  color:#208ED3;
}
.tabs .navigation li.active a{
  font-weight:600;
}
.install_main_packages_left .tabs .navigation li a{
  padding-left:36px;
}
.install_main_packages_left .tabs .navigation li a::before{
  content:'';
  width:18px;
  height:18px;
  background-size:cover;
  background-repeat:no-repeat;
  background-position:center;
  position:absolute;
  left:10px;
  top:16px;
}
.install_main_packages_left .tabs .navigation li:nth-child(1) a::before{
  background-image:url(../images/packages.svg);
}
.install_main_packages_left .tabs .navigation li.active:nth-child(1) a::before{
  background-image:url(../images/packagesactive.svg);
}
.install_main_packages_left .tabs .navigation li:nth-child(2) a::before{
  background-image:url(../images/sdk.svg);
}
.install_main_packages_left .tabs .navigation li.active:nth-child(2) a::before{
  background-image:url(../images/sdkactive.svg);
}
.install_main_packages_left .tabs .navigation li:nth-child(3) a::before{
  background-image:url(../images/import.svg);
}
.install_main_packages_left .tabs .navigation li.active:nth-child(3) a::before{
  background-image:url(../images/importactive.svg);
}
.install_main_packages_left .tabs .navigation li:nth-child(4) a::before{
  background-image:url(../images/other.svg);
}
.install_main_packages_left .tabs .navigation li.active:nth-child(4) a::before{
  background-image:url(../images/otheractive.svg);
}
.install_main_packages_left .tabs .navigation li:nth-child(5) a::before{
  background-image:url(../images/logout.svg);
}
.install_main_packages_left .tabs .navigation li.active:nth-child(5) a::before{
  background-image:url(../images/logout.svg);
}
.install_main_packages_right h3{
  font-size:24px;
  font-weight:600;
  margin-bottom:10px;
}
.install_main_packages_right p{
  font-size:14px;
  margin-bottom:4px;
}
.btn_new_install{
  margin:15px 0;
  display:flex;
  align-items:center;
  justify-content:space-between;
}
.btn_new_install .install_packages_add{
  background:#208ED3;
  padding:12px 20px;
  border-radius:50px;
  font-size:14px;
  color:#fff !important;
  display:inline-flex;
  align-items:center;
  transition:0.5s;
  box-shadow:0px 5px 10px rgba(0, 0, 0, .18);
}
.btn_new_install .install_packages_add:hover{
  opacity:0.8;
}
.btn_new_install .install_packages_add svg{
  fill:#fff;
  margin-right:6px;
}
.install_package_search{
  width:240px;
  overflow:hidden;
}
.install_package_search input{
  width:100%;
  border-radius:50px;
  padding:10px 20px;
}
/*ning instructions*/
.ning_instructions blockquote{
  margin-inline-start:-20px;
}
.install_main_packages_right .global_form .form-options-wrapper li{
  margin-bottom:10px;
}
.admin_import_ning_form fieldset .form-wrapper{
  margin-bottom:20px;
}
.sdk_build_moreinfo_container .sdk_build_location p{
  margin:0;
}
.sdk_build_moreinfo_container .sdk_build_description{
  margin-top:0;
}
table.sdk_table.manage th input.checkbox{
  display:block !important;
}