<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Install_Import_Phpfox_UserFields extends Install_Import_Phpfox_AbstractFields
{

  protected $_toTableTruncate = false;
  protected $_fromResourceType = 'profile';
  protected $_fromAlternateResourceType = 'user';
  protected $_toResourceType = 'user';
  protected $_useProfileType = true;
  protected $_priority = 5000;

  protected function _run()
  {
    //$this->_message('Not implemented', 2);
  }
}
