<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<h3>Add Packages</h3>

<?php
  // Navigation
  echo $this->render('_installMenu.tpl')
?>

<br />


<?php if( $this->form ): ?>

  <?php echo $this->form->render($this) ?>

<?php else: ?>

  <form action="<?php echo $this->url() ?>">
    <?php echo $this->formRadio('location', null, array(), $this->paths) ?>
    <br />
    <br />
    <?php echo $this->formButton('submit', 'Select Path', array('type' => 'submit')) ?>

  </form>

<?php endif; ?>
