<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<div class="sdk" id="content2">
  <h3><?php echo $this->translate("Create a Package")  ?></h3>
  <div class="settings">
    <?php echo $this->form->render($this) ?>
  </div>
</div>
