<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<div class="admin_packages_steps_wrapper">
  <div class="admin_packages_steps">
    <?php
      $c = count($this->installNavigation);
      $i = 0;
    ?>
    <?php foreach( $this->installNavigation as $page ): $i++; ?>
      <a href="<?php echo $page->getUri() ?>"<?php if( $page->isActive() ): ?> class="active"<?php endif; ?>>
        <?php echo $page->getLabel() ?>
      </a>
      <?php if( $i != $c ) echo "&nbsp;»&nbsp;" ?>
    <?php endforeach; ?>
  </div>
</div>
