<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Install_View_Helper_PackageSelectSimple extends Zend_View_Helper_Abstract
{
  public function packageSelectSimple($packageKey)
  {
    ob_start();
    ?>
      <li class="file file-success package_<?php echo str_replace('.', '_', $packageKey) ?>">
        <span class="file-name">
          <?php echo $packageKey ?>
        </span>
        <span class="file-info">
          <span class="file-message">
            Pending extraction.
          </span>
        </span>
      </li>
    <?php
    return ob_get_clean();
  }
}
