<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<h3>
  Install Packages
</h3>

<br />

<p>
  The installer has been upgraded, and requires a restart of the install
  process. The files have already been copied, so if you are asked to choose
  either overwrite or skip, select skip, otherwise continue normally.
</p>

<br />
<br />

<div>
  <?php
    $action = ( empty($this->extractedPackageKeys)
        ? $this->url(array('action' => 'select'))
        : $this->url(array('action' => 'prepare')) );
  ?>
  <form method="post" action="<?php echo $action ?>">
    <button type="submit">Restart</button>
    <?php foreach( (array) $this->extractedPackageKeys as $key ): ?>
      <input type="hidden" name="packages[]" value="<?php echo $key ?>" />
    <?php endforeach; ?>
  </form>
</div>
